;**********************************************************************
;   This file is a basic code template for assembly code generation   *
;   on the PICmicro PIC16F628. This file contains the basic code      *
;   building blocks to build upon.                                    *  
;                                                                     *
;   If interrupts are not used all code presented between the ORG     *
;   0x004 directive and the label main can be removed. In addition    *
;   the variable assignments for 'w_temp' and 'status_temp' can       *
;   be removed.                                                       *                         
;                                                                     *
;   Refer to the MPASM User's Guide for additional information on     *
;   features of the assembler (Document DS33014).                     *
;                                                                     *
;   Refer to the respective PICmicro data sheet for additional        *
;   information on the instruction set.                               *
;                                                                     *
;   Template file assembled with MPLAB V4.00.00 and MPASM V2.20.12    *
;                                                                     *
;**********************************************************************
;                                                                     *
;    Filename:	    xxx.asm                                           *
;    Date:                                                            *
;    File Version:                                                    *
;                                                                     *
;    Author:                                                          *
;    Company:                                                         *
;                                                                     * 
;                                                                     *
;**********************************************************************
;                                                                     *
;    Files required:                                                  *
;                                                                     *
;                                                                     *
;                                                                     *
;**********************************************************************
;                                                                     *
;    Notes:                                                           *
;                                                                     *
;                                                                     *
;                                                                     *
;                                                                     *
;**********************************************************************



	list      p=16f628            ; list directive to define processor
	#include <p16f628.inc>        ; processor specific variable definitions
	
	__CONFIG _CP_OFF & _WDT_ON & _BODEN_ON & _PWRTE_ON & _ER_OSC_CLKOUT & _MCLRE_ON & _LVP_ON

; '__CONFIG' directive is used to embed configuration data within .asm file.
; The lables following the directive are located in the respective .inc file.
; See respective data sheet for additional information on configuration word.




;***** VARIABLE DEFINITIONS
w_temp        EQU     0x70        ; variable used for context saving 
status_temp   EQU     0x71        ; variable used for context saving





;Free RAM
; 0x20-0x6F:BANK0
; 0x70-0x7F:BANK0-3
; 0xA0-0xEF:BANK1
; 0x120-0x12F:BANK2

CNT0            EQU             20H             ;Counter for Timer
CNT1            EQU             21H             ;Counter for Timer
CNT2            EQU             22H             ;Counter for Timer


;**********************************************************************
		ORG     0x000             ; reset vector
		goto    MAIN              ; 
		

MAIN   

					         
                BSF             STATUS,RP0      ;Set Page 1
                MOVLW           0dfH            ;
                MOVWF           TRISB           ;PB5 is output
 	        BCF             STATUS,RP0      ;Set Page 0
MAINLP
                CLRF            PORTB           ;Output 0x00 to Port A
                CALL            SECTIM          ;Wait
                MOVLW           0FFH            ;Get FF
                MOVWF           PORTB           ;Output 0xff to Port A
                CALL            SECTIM          ;Wait
	        GOTO            MAINLP          ;Jump to Loop
   
;***************************
;  Timer Subroutines
;***************************

TIM10
                MOVLW           0F9H 
                MOVWF           CNT0 
TIMLP1		NOP
                DECFSZ          CNT0,F
                GOTO            TIMLP1
                RETURN                


TIM100
                MOVLW           0F9H        
                MOVWF           CNT1
TIMLP2
                CALL            TIM10
                DECFSZ          CNT1,F		
                GOTO            TIMLP2		
                RETURN               
                                       

SECTIM
                MOVLW          20
                MOVWF           CNT2          
TIMLP3
                CALL            TIM100
                DECFSZ          CNT2,F
                GOTO            TIMLP3
                RETURN


		END                       
		

